/*
** Copyright (c) 2004 CA.  All rights reserved.  
** This software may not be duplicated, disclosed or reproduced in whole or 
** in part for any purpose except as authorized by the applicable license agreement, 
** without the express written authorization of CA. All authorized reproductions 
** must be marked with this language.  
**
** TO THE EXTENT PERMITTED BY APPLICABLE LAW, CA PROVIDES THIS 
** SOFTWARE AS IS WITHOUT WARRANTY OF ANY KIND, INCLUDING 
** WITHOUT LIMITATION, ANY IMPLIED WARRANTIES OF MERCHANTABILITY, 
** FITNESS FOR A PARTICULAR PURPOSE OR NONINFRINGEMENT.  IN NO EVENT 
** WILL CA BE LIABLE TO THE END USER OR ANY THIRD PARTY FOR ANY LOSS 
** OR DAMAGE, DIRECT OR INDIRECT, FROM THE USE OF THIS MATERIAL, 
** INCLUDING WITHOUT LIMITATION, LOST PROFITS, BUSINESS 
** INTERRUPTION, GOODWILL, OR LOST DATA, EVEN IF CA IS EXPRESSLY 
** ADVISED OF SUCH LOSS OR DAMAGE.
*/
// SiteMinder Java Authorization API sample Active Response.


import com.netegrity.policyserver.smapi.*;


/**
 * ActiveResponseSample
 *
 * This Active Response will return the common name(cn) of the user if the user belongs to
 * the organizational unit specified in the invoke method's String parameter param.
 *
 * For example, put this in the Active Response field:
 *
 *   <@ lib="smjavaapi" func="JavaActiveExpression" param="com.netegrity.sdk.javaazapi.ActiveResponseSample Human Resources" @>
 *
 * and "Human Resources" will be passed as the value for param to the invoke method
 * of the com.netegrity.sdk.javaazapi.ActiveResponseSample class.
 */

public class GetIdleTimeOutActiveResponse
    implements ActiveExpression
{
    /**
     * SiteMinder calls init() once to initialize this class before making
     * calls to invoke()
     *
     * @param context    the context to access Siteminder APIs
     * @return   0 if initialization succeeded, -1 if there was an error
     */

    public int
    init(APIContext context)
        throws Exception
    {
        // This example needs no initialization so just return "success"
        return 0;
    }


    /**
     * SiteMinder calls this function to evaluate the Active Response.
     *
     * This method will return the username if the user belongs to
     * the organizational unit specified in the parameter param.
     *
     * @param context   provides access to the Siteminder API contexts
     * @param param     an organizational unit name
     * @return          (1) if the app specific data is not set:
     *                  returns the username if the user's organizational unit[s] include
     *                  the one passed as param, otherwise null and an explanatory message will
     *                  be returned via the context's setErrorText method.
     *                  (2) if the app specific data is set:
     *                  returns the app specific data.
     * @exception       throws IllegalArgumentException if receives a null context
     *
     */

    public String
    invoke(ActiveExpressionContext context,
           String param)
        throws Exception
    {
	String idleTimeout ;
	
	
	SessionInfoContext sInfoCtx= new SessionInfoContext(context);
	APIContext apiContext = context.getAPIContext();
	
	long toRet = sInfoCtx.getIdleTimeout();
	if (toRet != -1)
	{
		//Logger.logInfo("Session  IdleTimeout " + toRet );
		logInPSTrace(apiContext, "Session  IdleTimeout  : " + String.valueOf(toRet));
		idleTimeout = String.valueOf(toRet);
	}
	else
	{
		logInPSTrace(apiContext, "FAILED to get Session IdleTimeout");
		idleTimeout = new String("ERROR");
	}
	return idleTimeout;
    }
    
    void logInPSTrace(APIContext apiContext, String msg) {
   	// Log message into Policy Server Trace Log
	apiContext.trace(this.getClass().getSimpleName(),
   		this.getClass().getSimpleName()+":: ['" + msg + "']");
       }


    /**
     * SiteMinder calls release() once when it is shutting down so this class can
     * perform its own rundown porcedure
     *
     * @param context    the context to access Siteminder APIs
     * @return   0 if shutdown succeeded, -1 if there was an error
     */

    public int
    release(APIContext context)
        throws Exception
    {
        // This example needs no shutdown so just return "success"
        return 0;
    }
}

// end of file ActiveResponseSample.java
